# Generated by Django 2.0.5 on 2019-07-16 12:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sidekick', '0003_update_task_model'),
    ]

    operations = [
        migrations.AddField(
            model_name='task',
            name='finished_at',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='task',
            name='started_at',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='task',
            name='status',
            field=models.CharField(choices=[('FAILED', 'Failed'), ('IN_PROGRESS', 'In Progress'), ('SLEEPING', 'Sleeping'), ('SUCCESS', 'Success')], default='SLEEPING', max_length=11),
        ),
    ]
